aboutsummaryrefslogtreecommitdiff
path: root/emms-streams.el
diff options
context:
space:
mode:
authorMichael Olson <mwolson@gnu.org>2007-01-05 23:06:00 +0000
committerMichael Olson <mwolson@gnu.org>2007-01-05 23:06:00 +0000
commitef7fe16f8b6a1283012099998c4abea2818abd93 (patch)
treed9c7341d6376d418f603c24beebb1d623fa61731 /emms-streams.el
parent11b83c0e196570462740e544d0b86bbce14a1c44 (diff)
Add support for playing Last.fm streams using emms-streams interface
darcs-hash:20070105230616-1bfb2-51c5cd5cdac1b0ab9daee569c4258296a030cdf3.gz
Diffstat (limited to 'emms-streams.el')
-rw-r--r--emms-streams.el12
1 files changed, 7 insertions, 5 deletions
diff --git a/emms-streams.el b/emms-streams.el
index e464a12..3bb62e3 100644
--- a/emms-streams.el
+++ b/emms-streams.el
@@ -88,8 +88,10 @@ needed info.")
"The EMMS playlist buffer associated with emms-streams.")
;; Format: (("descriptive name" url feed-number type))
;; type could be either url or playlist. If url, then it represents a
;; direct IP, otherwite it's a stream playlist
(defvar emms-stream-default-list
'(("SomaFM: Beatblender"
"http://www.somafm.com/beatblender.pls" 1 streamlist)
@@ -384,8 +386,8 @@ Don't forget to run `emms-stream-save-bookmarks-file' after !"
(read-string "URL: ")
nil
(completing-read
- "Type (url or streamlist): "
- (mapcar #'list '("url" "streamlist")))))
+ "Type (url, streamlist, or lastfm): "
+ (mapcar #'list '("url" "streamlist" "lastfm")))))
(unless fd (setq fd (emms-stream-determine-fd name)))
(let* ((line (emms-line-number-at-pos (point)))
(index (+ (/ line 2) 1)))
@@ -415,7 +417,7 @@ Don't forget to save your modifications !"
(emms-stream-url bookmark)))
(fd (read-from-minibuffer "Feed Descriptor: "
(int-to-string (emms-stream-fd bookmark))))
- (type (read-from-minibuffer "Type (url or streamlist): "
+ (type (read-from-minibuffer "Type (url, streamlist, or lastfm): "
(format "%s" (emms-stream-type bookmark)))))
(emms-stream-delete-bookmark)
(emms-stream-add-bookmark name url (string-to-number fd) type)))
@@ -88,8 +88,10 @@ needed info.")
"The EMMS playlist buffer associated with emms-streams.")
;; Format: (("descriptive name" url feed-number type))
-;; type could be either url or playlist. If url, then it represents a
-;; direct IP, otherwite it's a stream playlist
+;;
+;; type could be either url, playlist, or lastfm. If url, then it
+;; represents a direct IP, if streamlist it's a stream playlist, if
+;; lastfm it's a lastfm station
(defvar emms-stream-default-list
'(("SomaFM: Beatblender"